@@ -42,6 +42,8 @@ from .type_defs import (
     CreateSipRuleResponseTypeDef,
     CreateVoiceConnectorGroupResponseTypeDef,
     CreateVoiceConnectorResponseTypeDef,
+    CreateVoiceProfileDomainResponseTypeDef,
+    CreateVoiceProfileResponseTypeDef,
     CredentialTypeDef,
     DisassociatePhoneNumbersFromVoiceConnectorGroupResponseTypeDef,
     DisassociatePhoneNumbersFromVoiceConnectorResponseTypeDef,
@@ -57,6 +59,7 @@ from .type_defs import (
     GetSipMediaApplicationLoggingConfigurationResponseTypeDef,
     GetSipMediaApplicationResponseTypeDef,
     GetSipRuleResponseTypeDef,
+    GetSpeakerSearchTaskResponseTypeDef,
     GetVoiceConnectorEmergencyCallingConfigurationResponseTypeDef,
     GetVoiceConnectorGroupResponseTypeDef,
     GetVoiceConnectorLoggingConfigurationResponseTypeDef,
@@ -66,6 +69,9 @@ from .type_defs import (
     GetVoiceConnectorStreamingConfigurationResponseTypeDef,
     GetVoiceConnectorTerminationHealthResponseTypeDef,
     GetVoiceConnectorTerminationResponseTypeDef,
+    GetVoiceProfileDomainResponseTypeDef,
+    GetVoiceProfileResponseTypeDef,
+    GetVoiceToneAnalysisTaskResponseTypeDef,
     ListAvailableVoiceConnectorRegionsResponseTypeDef,
     ListPhoneNumberOrdersResponseTypeDef,
     ListPhoneNumbersResponseTypeDef,
@@ -73,9 +79,12 @@ from .type_defs import (
     ListSipMediaApplicationsResponseTypeDef,
     ListSipRulesResponseTypeDef,
     ListSupportedPhoneNumberCountriesResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     ListVoiceConnectorGroupsResponseTypeDef,
     ListVoiceConnectorsResponseTypeDef,
     ListVoiceConnectorTerminationCredentialsResponseTypeDef,
+    ListVoiceProfileDomainsResponseTypeDef,
+    ListVoiceProfilesResponseTypeDef,
     LoggingConfigurationTypeDef,
     OriginationTypeDef,
     PutSipMediaApplicationAlexaSkillConfigurationResponseTypeDef,
@@ -88,11 +97,15 @@ from .type_defs import (
     PutVoiceConnectorTerminationResponseTypeDef,
     RestorePhoneNumberResponseTypeDef,
     SearchAvailablePhoneNumbersResponseTypeDef,
+    ServerSideEncryptionConfigurationTypeDef,
     SipMediaApplicationAlexaSkillConfigurationTypeDef,
     SipMediaApplicationEndpointTypeDef,
     SipMediaApplicationLoggingConfigurationTypeDef,
     SipRuleTargetApplicationTypeDef,
+    StartSpeakerSearchTaskResponseTypeDef,
+    StartVoiceToneAnalysisTaskResponseTypeDef,
     StreamingConfigurationTypeDef,
+    TagTypeDef,
     TerminationTypeDef,
     UpdatePhoneNumberRequestItemTypeDef,
     UpdatePhoneNumberResponseTypeDef,
@@ -102,6 +115,8 @@ from .type_defs import (
     UpdateSipRuleResponseTypeDef,
     UpdateVoiceConnectorGroupResponseTypeDef,
     UpdateVoiceConnectorResponseTypeDef,
+    UpdateVoiceProfileDomainResponseTypeDef,
+    UpdateVoiceProfileResponseTypeDef,
     ValidateE911AddressResponseTypeDef,
     VoiceConnectorItemTypeDef,
     VoiceConnectorSettingsTypeDef,
@@ -130,12 +145,14 @@ class Exceptions:
     ClientError: Type[BotocoreClientError]
     ConflictException: Type[BotocoreClientError]
     ForbiddenException: Type[BotocoreClientError]
+    GoneException: Type[BotocoreClientError]
     NotFoundException: Type[BotocoreClientError]
     ResourceLimitExceededException: Type[BotocoreClientError]
     ServiceFailureException: Type[BotocoreClientError]
     ServiceUnavailableException: Type[BotocoreClientError]
     ThrottledClientException: Type[BotocoreClientError]
     UnauthorizedClientException: Type[BotocoreClientError]
+    UnprocessableEntityException: Type[BotocoreClientError]
 
 
 class ChimeSDKVoiceClient(BaseClient):
@@ -317,6 +334,34 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#create_voice_connector_group)
         """
 
+    def create_voice_profile(
+        self, *, SpeakerSearchTaskId: str
+    ) -> CreateVoiceProfileResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/CreateVoiceProfile).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.create_voice_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#create_voice_profile)
+        """
+
+    def create_voice_profile_domain(
+        self,
+        *,
+        Name: str,
+        ServerSideEncryptionConfiguration: ServerSideEncryptionConfigurationTypeDef,
+        Description: str = ...,
+        ClientRequestToken: str = ...,
+        Tags: Sequence[TagTypeDef] = ...
+    ) -> CreateVoiceProfileDomainResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/CreateVoiceProfileDomain).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.create_voice_profile_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#create_voice_profile_domain)
+        """
+
     def delete_phone_number(self, *, PhoneNumberId: str) -> EmptyResponseMetadataTypeDef:
         """
         See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
@@ -443,6 +488,26 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#delete_voice_connector_termination_credentials)
         """
 
+    def delete_voice_profile(self, *, VoiceProfileId: str) -> EmptyResponseMetadataTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/DeleteVoiceProfile).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.delete_voice_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#delete_voice_profile)
+        """
+
+    def delete_voice_profile_domain(
+        self, *, VoiceProfileDomainId: str
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/DeleteVoiceProfileDomain).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.delete_voice_profile_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#delete_voice_profile_domain)
+        """
+
     def disassociate_phone_numbers_from_voice_connector(
         self, *, VoiceConnectorId: str, E164PhoneNumbers: Sequence[str]
     ) -> DisassociatePhoneNumbersFromVoiceConnectorResponseTypeDef:
@@ -570,6 +635,17 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#get_sip_rule)
         """
 
+    def get_speaker_search_task(
+        self, *, VoiceConnectorId: str, SpeakerSearchTaskId: str
+    ) -> GetSpeakerSearchTaskResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/GetSpeakerSearchTask).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.get_speaker_search_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#get_speaker_search_task)
+        """
+
     def get_voice_connector(self, *, VoiceConnectorId: str) -> GetVoiceConnectorResponseTypeDef:
         """
         See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
@@ -667,6 +743,37 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#get_voice_connector_termination_health)
         """
 
+    def get_voice_profile(self, *, VoiceProfileId: str) -> GetVoiceProfileResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/GetVoiceProfile).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.get_voice_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#get_voice_profile)
+        """
+
+    def get_voice_profile_domain(
+        self, *, VoiceProfileDomainId: str
+    ) -> GetVoiceProfileDomainResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/GetVoiceProfileDomain).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.get_voice_profile_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#get_voice_profile_domain)
+        """
+
+    def get_voice_tone_analysis_task(
+        self, *, VoiceConnectorId: str, VoiceToneAnalysisTaskId: str, IsCaller: bool
+    ) -> GetVoiceToneAnalysisTaskResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/GetVoiceToneAnalysisTask).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.get_voice_tone_analysis_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#get_voice_tone_analysis_task)
+        """
+
     def list_available_voice_connector_regions(
         self,
     ) -> ListAvailableVoiceConnectorRegionsResponseTypeDef:
@@ -756,6 +863,15 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#list_supported_phone_number_countries)
         """
 
+    def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/ListTagsForResource).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#list_tags_for_resource)
+        """
+
     def list_voice_connector_groups(
         self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListVoiceConnectorGroupsResponseTypeDef:
@@ -789,6 +905,28 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#list_voice_connectors)
         """
 
+    def list_voice_profile_domains(
+        self, *, NextToken: str = ..., MaxResults: int = ...
+    ) -> ListVoiceProfileDomainsResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/ListVoiceProfileDomains).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.list_voice_profile_domains)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#list_voice_profile_domains)
+        """
+
+    def list_voice_profiles(
+        self, *, VoiceProfileDomainId: str, NextToken: str = ..., MaxResults: int = ...
+    ) -> ListVoiceProfilesResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/ListVoiceProfiles).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.list_voice_profiles)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#list_voice_profiles)
+        """
+
     def put_sip_media_application_alexa_skill_configuration(
         self,
         *,
@@ -932,6 +1070,82 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#search_available_phone_numbers)
         """
 
+    def start_speaker_search_task(
+        self,
+        *,
+        VoiceConnectorId: str,
+        TransactionId: str,
+        VoiceProfileDomainId: str,
+        ClientRequestToken: str = ...
+    ) -> StartSpeakerSearchTaskResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/StartSpeakerSearchTask).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.start_speaker_search_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#start_speaker_search_task)
+        """
+
+    def start_voice_tone_analysis_task(
+        self,
+        *,
+        VoiceConnectorId: str,
+        TransactionId: str,
+        LanguageCode: Literal["en-US"],
+        ClientRequestToken: str = ...
+    ) -> StartVoiceToneAnalysisTaskResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/StartVoiceToneAnalysisTask).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.start_voice_tone_analysis_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#start_voice_tone_analysis_task)
+        """
+
+    def stop_speaker_search_task(
+        self, *, VoiceConnectorId: str, SpeakerSearchTaskId: str
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/StopSpeakerSearchTask).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.stop_speaker_search_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#stop_speaker_search_task)
+        """
+
+    def stop_voice_tone_analysis_task(
+        self, *, VoiceConnectorId: str, VoiceToneAnalysisTaskId: str
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/StopVoiceToneAnalysisTask).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.stop_voice_tone_analysis_task)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#stop_voice_tone_analysis_task)
+        """
+
+    def tag_resource(
+        self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/TagResource).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.tag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#tag_resource)
+        """
+
+    def untag_resource(
+        self, *, ResourceARN: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/UntagResource).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.untag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#untag_resource)
+        """
+
     def update_global_settings(
         self, *, VoiceConnector: VoiceConnectorSettingsTypeDef = ...
     ) -> EmptyResponseMetadataTypeDef:
@@ -1051,6 +1265,28 @@ class ChimeSDKVoiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#update_voice_connector_group)
         """
 
+    def update_voice_profile(
+        self, *, VoiceProfileId: str, SpeakerSearchTaskId: str
+    ) -> UpdateVoiceProfileResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/UpdateVoiceProfile).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.update_voice_profile)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#update_voice_profile)
+        """
+
+    def update_voice_profile_domain(
+        self, *, VoiceProfileDomainId: str, Name: str = ..., Description: str = ...
+    ) -> UpdateVoiceProfileDomainResponseTypeDef:
+        """
+        See also: [AWS API Documentation](https://docs.aws.amazon.com/goto/WebAPI/chime-
+        sdk-voice-2022-08-03/UpdateVoiceProfileDomain).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-voice.html#ChimeSDKVoice.Client.update_voice_profile_domain)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_voice/client/#update_voice_profile_domain)
+        """
+
     def validate_e911_address(
         self,
         *,
