@@ -25,6 +25,7 @@ __all__ = (
     "CapabilityType",
     "ErrorCodeType",
     "GeoMatchLevelType",
+    "LanguageCodeType",
     "ListSipMediaApplicationsPaginatorName",
     "ListSipRulesPaginatorName",
     "NotificationTargetType",
@@ -70,6 +71,7 @@ ErrorCodeType = Literal[
     "VoiceConnectorGroupAssociationsExist",
 ]
 GeoMatchLevelType = Literal["AreaCode", "Country"]
+LanguageCodeType = Literal["en-US"]
 ListSipMediaApplicationsPaginatorName = Literal["list_sip_media_applications"]
 ListSipRulesPaginatorName = Literal["list_sip_rules"]
 NotificationTargetType = Literal["EventBridge", "SNS", "SQS"]
@@ -269,6 +271,7 @@ ServiceName = Literal[
     "importexport",
     "inspector",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -287,6 +290,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
