@@ -36,6 +36,10 @@ from .literals import (
     VoiceConnectorAwsRegionType,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -50,6 +54,7 @@ __all__ = (
     "AssociatePhoneNumbersWithVoiceConnectorRequestRequestTypeDef",
     "BatchDeletePhoneNumberRequestRequestTypeDef",
     "UpdatePhoneNumberRequestItemTypeDef",
+    "CallDetailsTypeDef",
     "CandidateAddressTypeDef",
     "CreatePhoneNumberOrderRequestRequestTypeDef",
     "GeoMatchParamsTypeDef",
@@ -60,6 +65,10 @@ __all__ = (
     "VoiceConnectorItemTypeDef",
     "CreateVoiceConnectorRequestRequestTypeDef",
     "VoiceConnectorTypeDef",
+    "ServerSideEncryptionConfigurationTypeDef",
+    "TagTypeDef",
+    "CreateVoiceProfileRequestRequestTypeDef",
+    "VoiceProfileTypeDef",
     "CredentialTypeDef",
     "DNISEmergencyCallingConfigurationTypeDef",
     "DeletePhoneNumberRequestRequestTypeDef",
@@ -74,6 +83,8 @@ __all__ = (
     "DeleteVoiceConnectorStreamingConfigurationRequestRequestTypeDef",
     "DeleteVoiceConnectorTerminationCredentialsRequestRequestTypeDef",
     "DeleteVoiceConnectorTerminationRequestRequestTypeDef",
+    "DeleteVoiceProfileDomainRequestRequestTypeDef",
+    "DeleteVoiceProfileRequestRequestTypeDef",
     "DisassociatePhoneNumbersFromVoiceConnectorGroupRequestRequestTypeDef",
     "DisassociatePhoneNumbersFromVoiceConnectorRequestRequestTypeDef",
     "VoiceConnectorSettingsTypeDef",
@@ -86,6 +97,7 @@ __all__ = (
     "SipMediaApplicationLoggingConfigurationTypeDef",
     "GetSipMediaApplicationRequestRequestTypeDef",
     "GetSipRuleRequestRequestTypeDef",
+    "GetSpeakerSearchTaskRequestRequestTypeDef",
     "GetVoiceConnectorEmergencyCallingConfigurationRequestRequestTypeDef",
     "GetVoiceConnectorGroupRequestRequestTypeDef",
     "GetVoiceConnectorLoggingConfigurationRequestRequestTypeDef",
@@ -99,6 +111,9 @@ __all__ = (
     "TerminationHealthTypeDef",
     "GetVoiceConnectorTerminationRequestRequestTypeDef",
     "TerminationTypeDef",
+    "GetVoiceProfileDomainRequestRequestTypeDef",
+    "GetVoiceProfileRequestRequestTypeDef",
+    "GetVoiceToneAnalysisTaskRequestRequestTypeDef",
     "ListPhoneNumberOrdersRequestRequestTypeDef",
     "ListPhoneNumbersRequestRequestTypeDef",
     "ListProxySessionsRequestRequestTypeDef",
@@ -107,9 +122,15 @@ __all__ = (
     "ListSipRulesRequestRequestTypeDef",
     "ListSupportedPhoneNumberCountriesRequestRequestTypeDef",
     "PhoneNumberCountryTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListVoiceConnectorGroupsRequestRequestTypeDef",
     "ListVoiceConnectorTerminationCredentialsRequestRequestTypeDef",
     "ListVoiceConnectorsRequestRequestTypeDef",
+    "ListVoiceProfileDomainsRequestRequestTypeDef",
+    "VoiceProfileDomainSummaryTypeDef",
+    "ListVoiceProfilesRequestRequestTypeDef",
+    "VoiceProfileSummaryTypeDef",
+    "MediaInsightsConfigurationTypeDef",
     "OrderedPhoneNumberTypeDef",
     "OriginationRouteTypeDef",
     "ParticipantTypeDef",
@@ -118,12 +139,20 @@ __all__ = (
     "PutVoiceConnectorProxyRequestRequestTypeDef",
     "RestorePhoneNumberRequestRequestTypeDef",
     "SearchAvailablePhoneNumbersRequestRequestTypeDef",
+    "SpeakerSearchResultTypeDef",
+    "StartSpeakerSearchTaskRequestRequestTypeDef",
+    "StartVoiceToneAnalysisTaskRequestRequestTypeDef",
+    "StopSpeakerSearchTaskRequestRequestTypeDef",
+    "StopVoiceToneAnalysisTaskRequestRequestTypeDef",
     "StreamingNotificationTargetTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "UpdatePhoneNumberRequestRequestTypeDef",
     "UpdatePhoneNumberSettingsRequestRequestTypeDef",
     "UpdateProxySessionRequestRequestTypeDef",
     "UpdateSipMediaApplicationCallRequestRequestTypeDef",
     "UpdateVoiceConnectorRequestRequestTypeDef",
+    "UpdateVoiceProfileDomainRequestRequestTypeDef",
+    "UpdateVoiceProfileRequestRequestTypeDef",
     "ValidateE911AddressRequestRequestTypeDef",
     "AssociatePhoneNumbersWithVoiceConnectorGroupResponseTypeDef",
     "AssociatePhoneNumbersWithVoiceConnectorResponseTypeDef",
@@ -137,6 +166,7 @@ __all__ = (
     "ListVoiceConnectorTerminationCredentialsResponseTypeDef",
     "SearchAvailablePhoneNumbersResponseTypeDef",
     "BatchUpdatePhoneNumberRequestRequestTypeDef",
+    "VoiceToneAnalysisTaskTypeDef",
     "ValidateE911AddressResponseTypeDef",
     "CreateProxySessionRequestRequestTypeDef",
     "CreateSipMediaApplicationCallResponseTypeDef",
@@ -154,6 +184,13 @@ __all__ = (
     "GetVoiceConnectorResponseTypeDef",
     "ListVoiceConnectorsResponseTypeDef",
     "UpdateVoiceConnectorResponseTypeDef",
+    "VoiceProfileDomainTypeDef",
+    "CreateVoiceProfileDomainRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "CreateVoiceProfileResponseTypeDef",
+    "GetVoiceProfileResponseTypeDef",
+    "UpdateVoiceProfileResponseTypeDef",
     "PutVoiceConnectorTerminationCredentialsRequestRequestTypeDef",
     "EmergencyCallingConfigurationTypeDef",
     "GetGlobalSettingsResponseTypeDef",
@@ -176,11 +213,16 @@ __all__ = (
     "ListSipMediaApplicationsRequestListSipMediaApplicationsPaginateTypeDef",
     "ListSipRulesRequestListSipRulesPaginateTypeDef",
     "ListSupportedPhoneNumberCountriesResponseTypeDef",
+    "ListVoiceProfileDomainsResponseTypeDef",
+    "ListVoiceProfilesResponseTypeDef",
     "PhoneNumberOrderTypeDef",
     "OriginationTypeDef",
     "ProxySessionTypeDef",
     "PhoneNumberTypeDef",
+    "SpeakerSearchDetailsTypeDef",
     "StreamingConfigurationTypeDef",
+    "GetVoiceToneAnalysisTaskResponseTypeDef",
+    "StartVoiceToneAnalysisTaskResponseTypeDef",
     "CreateSipMediaApplicationResponseTypeDef",
     "GetSipMediaApplicationResponseTypeDef",
     "ListSipMediaApplicationsResponseTypeDef",
@@ -193,6 +235,9 @@ __all__ = (
     "GetVoiceConnectorGroupResponseTypeDef",
     "ListVoiceConnectorGroupsResponseTypeDef",
     "UpdateVoiceConnectorGroupResponseTypeDef",
+    "CreateVoiceProfileDomainResponseTypeDef",
+    "GetVoiceProfileDomainResponseTypeDef",
+    "UpdateVoiceProfileDomainResponseTypeDef",
     "GetVoiceConnectorEmergencyCallingConfigurationResponseTypeDef",
     "PutVoiceConnectorEmergencyCallingConfigurationRequestRequestTypeDef",
     "PutVoiceConnectorEmergencyCallingConfigurationResponseTypeDef",
@@ -210,9 +255,12 @@ __all__ = (
     "ListPhoneNumbersResponseTypeDef",
     "RestorePhoneNumberResponseTypeDef",
     "UpdatePhoneNumberResponseTypeDef",
+    "SpeakerSearchTaskTypeDef",
     "GetVoiceConnectorStreamingConfigurationResponseTypeDef",
     "PutVoiceConnectorStreamingConfigurationRequestRequestTypeDef",
     "PutVoiceConnectorStreamingConfigurationResponseTypeDef",
+    "GetSpeakerSearchTaskResponseTypeDef",
+    "StartSpeakerSearchTaskResponseTypeDef",
 )
 
 AddressTypeDef = TypedDict(
@@ -328,6 +376,16 @@ class UpdatePhoneNumberRequestItemTypeDef(
     pass
 
 
+CallDetailsTypeDef = TypedDict(
+    "CallDetailsTypeDef",
+    {
+        "VoiceConnectorId": str,
+        "TransactionId": str,
+        "IsCaller": bool,
+    },
+    total=False,
+)
+
 CandidateAddressTypeDef = TypedDict(
     "CandidateAddressTypeDef",
     {
@@ -455,6 +513,41 @@ VoiceConnectorTypeDef = TypedDict(
     total=False,
 )
 
+ServerSideEncryptionConfigurationTypeDef = TypedDict(
+    "ServerSideEncryptionConfigurationTypeDef",
+    {
+        "KmsKeyArn": str,
+    },
+)
+
+TagTypeDef = TypedDict(
+    "TagTypeDef",
+    {
+        "Key": str,
+        "Value": str,
+    },
+)
+
+CreateVoiceProfileRequestRequestTypeDef = TypedDict(
+    "CreateVoiceProfileRequestRequestTypeDef",
+    {
+        "SpeakerSearchTaskId": str,
+    },
+)
+
+VoiceProfileTypeDef = TypedDict(
+    "VoiceProfileTypeDef",
+    {
+        "VoiceProfileId": str,
+        "VoiceProfileArn": str,
+        "VoiceProfileDomainId": str,
+        "CreatedTimestamp": datetime,
+        "UpdatedTimestamp": datetime,
+        "ExpirationTimestamp": datetime,
+    },
+    total=False,
+)
+
 CredentialTypeDef = TypedDict(
     "CredentialTypeDef",
     {
@@ -573,6 +666,20 @@ DeleteVoiceConnectorTerminationRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteVoiceProfileDomainRequestRequestTypeDef = TypedDict(
+    "DeleteVoiceProfileDomainRequestRequestTypeDef",
+    {
+        "VoiceProfileDomainId": str,
+    },
+)
+
+DeleteVoiceProfileRequestRequestTypeDef = TypedDict(
+    "DeleteVoiceProfileRequestRequestTypeDef",
+    {
+        "VoiceProfileId": str,
+    },
+)
+
 DisassociatePhoneNumbersFromVoiceConnectorGroupRequestRequestTypeDef = TypedDict(
     "DisassociatePhoneNumbersFromVoiceConnectorGroupRequestRequestTypeDef",
     {
@@ -663,6 +770,14 @@ GetSipRuleRequestRequestTypeDef = TypedDict(
     },
 )
 
+GetSpeakerSearchTaskRequestRequestTypeDef = TypedDict(
+    "GetSpeakerSearchTaskRequestRequestTypeDef",
+    {
+        "VoiceConnectorId": str,
+        "SpeakerSearchTaskId": str,
+    },
+)
+
 GetVoiceConnectorEmergencyCallingConfigurationRequestRequestTypeDef = TypedDict(
     "GetVoiceConnectorEmergencyCallingConfigurationRequestRequestTypeDef",
     {
@@ -767,6 +882,29 @@ TerminationTypeDef = TypedDict(
     total=False,
 )
 
+GetVoiceProfileDomainRequestRequestTypeDef = TypedDict(
+    "GetVoiceProfileDomainRequestRequestTypeDef",
+    {
+        "VoiceProfileDomainId": str,
+    },
+)
+
+GetVoiceProfileRequestRequestTypeDef = TypedDict(
+    "GetVoiceProfileRequestRequestTypeDef",
+    {
+        "VoiceProfileId": str,
+    },
+)
+
+GetVoiceToneAnalysisTaskRequestRequestTypeDef = TypedDict(
+    "GetVoiceToneAnalysisTaskRequestRequestTypeDef",
+    {
+        "VoiceConnectorId": str,
+        "VoiceToneAnalysisTaskId": str,
+        "IsCaller": bool,
+    },
+)
+
 ListPhoneNumberOrdersRequestRequestTypeDef = TypedDict(
     "ListPhoneNumberOrdersRequestRequestTypeDef",
     {
@@ -857,6 +995,13 @@ PhoneNumberCountryTypeDef = TypedDict(
     total=False,
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
+
 ListVoiceConnectorGroupsRequestRequestTypeDef = TypedDict(
     "ListVoiceConnectorGroupsRequestRequestTypeDef",
     {
@@ -882,6 +1027,72 @@ ListVoiceConnectorsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+ListVoiceProfileDomainsRequestRequestTypeDef = TypedDict(
+    "ListVoiceProfileDomainsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+VoiceProfileDomainSummaryTypeDef = TypedDict(
+    "VoiceProfileDomainSummaryTypeDef",
+    {
+        "VoiceProfileDomainId": str,
+        "VoiceProfileDomainArn": str,
+        "Name": str,
+        "Description": str,
+        "CreatedTimestamp": datetime,
+        "UpdatedTimestamp": datetime,
+    },
+    total=False,
+)
+
+_RequiredListVoiceProfilesRequestRequestTypeDef = TypedDict(
+    "_RequiredListVoiceProfilesRequestRequestTypeDef",
+    {
+        "VoiceProfileDomainId": str,
+    },
+)
+_OptionalListVoiceProfilesRequestRequestTypeDef = TypedDict(
+    "_OptionalListVoiceProfilesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListVoiceProfilesRequestRequestTypeDef(
+    _RequiredListVoiceProfilesRequestRequestTypeDef, _OptionalListVoiceProfilesRequestRequestTypeDef
+):
+    pass
+
+
+VoiceProfileSummaryTypeDef = TypedDict(
+    "VoiceProfileSummaryTypeDef",
+    {
+        "VoiceProfileId": str,
+        "VoiceProfileArn": str,
+        "VoiceProfileDomainId": str,
+        "CreatedTimestamp": datetime,
+        "UpdatedTimestamp": datetime,
+        "ExpirationTimestamp": datetime,
+    },
+    total=False,
+)
+
+MediaInsightsConfigurationTypeDef = TypedDict(
+    "MediaInsightsConfigurationTypeDef",
+    {
+        "Disabled": bool,
+        "ConfigurationArn": str,
+    },
+    total=False,
+)
+
 OrderedPhoneNumberTypeDef = TypedDict(
     "OrderedPhoneNumberTypeDef",
     {
@@ -982,6 +1193,79 @@ SearchAvailablePhoneNumbersRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+SpeakerSearchResultTypeDef = TypedDict(
+    "SpeakerSearchResultTypeDef",
+    {
+        "ConfidenceScore": float,
+        "VoiceProfileId": str,
+    },
+    total=False,
+)
+
+_RequiredStartSpeakerSearchTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredStartSpeakerSearchTaskRequestRequestTypeDef",
+    {
+        "VoiceConnectorId": str,
+        "TransactionId": str,
+        "VoiceProfileDomainId": str,
+    },
+)
+_OptionalStartSpeakerSearchTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalStartSpeakerSearchTaskRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class StartSpeakerSearchTaskRequestRequestTypeDef(
+    _RequiredStartSpeakerSearchTaskRequestRequestTypeDef,
+    _OptionalStartSpeakerSearchTaskRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredStartVoiceToneAnalysisTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredStartVoiceToneAnalysisTaskRequestRequestTypeDef",
+    {
+        "VoiceConnectorId": str,
+        "TransactionId": str,
+        "LanguageCode": Literal["en-US"],
+    },
+)
+_OptionalStartVoiceToneAnalysisTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalStartVoiceToneAnalysisTaskRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class StartVoiceToneAnalysisTaskRequestRequestTypeDef(
+    _RequiredStartVoiceToneAnalysisTaskRequestRequestTypeDef,
+    _OptionalStartVoiceToneAnalysisTaskRequestRequestTypeDef,
+):
+    pass
+
+
+StopSpeakerSearchTaskRequestRequestTypeDef = TypedDict(
+    "StopSpeakerSearchTaskRequestRequestTypeDef",
+    {
+        "VoiceConnectorId": str,
+        "SpeakerSearchTaskId": str,
+    },
+)
+
+StopVoiceToneAnalysisTaskRequestRequestTypeDef = TypedDict(
+    "StopVoiceToneAnalysisTaskRequestRequestTypeDef",
+    {
+        "VoiceConnectorId": str,
+        "VoiceToneAnalysisTaskId": str,
+    },
+)
+
 StreamingNotificationTargetTypeDef = TypedDict(
     "StreamingNotificationTargetTypeDef",
     {
@@ -990,6 +1274,14 @@ StreamingNotificationTargetTypeDef = TypedDict(
     total=False,
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": Sequence[str],
+    },
+)
+
 _RequiredUpdatePhoneNumberRequestRequestTypeDef = TypedDict(
     "_RequiredUpdatePhoneNumberRequestRequestTypeDef",
     {
@@ -1061,6 +1353,37 @@ UpdateVoiceConnectorRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateVoiceProfileDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateVoiceProfileDomainRequestRequestTypeDef",
+    {
+        "VoiceProfileDomainId": str,
+    },
+)
+_OptionalUpdateVoiceProfileDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateVoiceProfileDomainRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class UpdateVoiceProfileDomainRequestRequestTypeDef(
+    _RequiredUpdateVoiceProfileDomainRequestRequestTypeDef,
+    _OptionalUpdateVoiceProfileDomainRequestRequestTypeDef,
+):
+    pass
+
+
+UpdateVoiceProfileRequestRequestTypeDef = TypedDict(
+    "UpdateVoiceProfileRequestRequestTypeDef",
+    {
+        "VoiceProfileId": str,
+        "SpeakerSearchTaskId": str,
+    },
+)
+
 ValidateE911AddressRequestRequestTypeDef = TypedDict(
     "ValidateE911AddressRequestRequestTypeDef",
     {
@@ -1170,6 +1493,20 @@ BatchUpdatePhoneNumberRequestRequestTypeDef = TypedDict(
     },
 )
 
+VoiceToneAnalysisTaskTypeDef = TypedDict(
+    "VoiceToneAnalysisTaskTypeDef",
+    {
+        "VoiceToneAnalysisTaskId": str,
+        "VoiceToneAnalysisTaskStatus": str,
+        "CallDetails": CallDetailsTypeDef,
+        "CreatedTimestamp": datetime,
+        "UpdatedTimestamp": datetime,
+        "StartedTimestamp": datetime,
+        "StatusMessage": str,
+    },
+    total=False,
+)
+
 ValidateE911AddressResponseTypeDef = TypedDict(
     "ValidateE911AddressResponseTypeDef",
     {
@@ -1409,6 +1746,85 @@ UpdateVoiceConnectorResponseTypeDef = TypedDict(
     },
 )
 
+VoiceProfileDomainTypeDef = TypedDict(
+    "VoiceProfileDomainTypeDef",
+    {
+        "VoiceProfileDomainId": str,
+        "VoiceProfileDomainArn": str,
+        "Name": str,
+        "Description": str,
+        "ServerSideEncryptionConfiguration": ServerSideEncryptionConfigurationTypeDef,
+        "CreatedTimestamp": datetime,
+        "UpdatedTimestamp": datetime,
+    },
+    total=False,
+)
+
+_RequiredCreateVoiceProfileDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateVoiceProfileDomainRequestRequestTypeDef",
+    {
+        "Name": str,
+        "ServerSideEncryptionConfiguration": ServerSideEncryptionConfigurationTypeDef,
+    },
+)
+_OptionalCreateVoiceProfileDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateVoiceProfileDomainRequestRequestTypeDef",
+    {
+        "Description": str,
+        "ClientRequestToken": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateVoiceProfileDomainRequestRequestTypeDef(
+    _RequiredCreateVoiceProfileDomainRequestRequestTypeDef,
+    _OptionalCreateVoiceProfileDomainRequestRequestTypeDef,
+):
+    pass
+
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
+CreateVoiceProfileResponseTypeDef = TypedDict(
+    "CreateVoiceProfileResponseTypeDef",
+    {
+        "VoiceProfile": VoiceProfileTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetVoiceProfileResponseTypeDef = TypedDict(
+    "GetVoiceProfileResponseTypeDef",
+    {
+        "VoiceProfile": VoiceProfileTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateVoiceProfileResponseTypeDef = TypedDict(
+    "UpdateVoiceProfileResponseTypeDef",
+    {
+        "VoiceProfile": VoiceProfileTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 _RequiredPutVoiceConnectorTerminationCredentialsRequestRequestTypeDef = TypedDict(
     "_RequiredPutVoiceConnectorTerminationCredentialsRequestRequestTypeDef",
     {
@@ -1634,6 +2050,24 @@ ListSupportedPhoneNumberCountriesResponseTypeDef = TypedDict(
     },
 )
 
+ListVoiceProfileDomainsResponseTypeDef = TypedDict(
+    "ListVoiceProfileDomainsResponseTypeDef",
+    {
+        "VoiceProfileDomains": List[VoiceProfileDomainSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListVoiceProfilesResponseTypeDef = TypedDict(
+    "ListVoiceProfilesResponseTypeDef",
+    {
+        "VoiceProfiles": List[VoiceProfileSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 PhoneNumberOrderTypeDef = TypedDict(
     "PhoneNumberOrderTypeDef",
     {
@@ -1698,6 +2132,15 @@ PhoneNumberTypeDef = TypedDict(
     total=False,
 )
 
+SpeakerSearchDetailsTypeDef = TypedDict(
+    "SpeakerSearchDetailsTypeDef",
+    {
+        "Results": List[SpeakerSearchResultTypeDef],
+        "VoiceprintGenerationStatus": str,
+    },
+    total=False,
+)
+
 _RequiredStreamingConfigurationTypeDef = TypedDict(
     "_RequiredStreamingConfigurationTypeDef",
     {
@@ -1709,6 +2152,7 @@ _OptionalStreamingConfigurationTypeDef = TypedDict(
     "_OptionalStreamingConfigurationTypeDef",
     {
         "StreamingNotificationTargets": List[StreamingNotificationTargetTypeDef],
+        "MediaInsightsConfiguration": MediaInsightsConfigurationTypeDef,
     },
     total=False,
 )
@@ -1720,6 +2164,22 @@ class StreamingConfigurationTypeDef(
     pass
 
 
+GetVoiceToneAnalysisTaskResponseTypeDef = TypedDict(
+    "GetVoiceToneAnalysisTaskResponseTypeDef",
+    {
+        "VoiceToneAnalysisTask": VoiceToneAnalysisTaskTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartVoiceToneAnalysisTaskResponseTypeDef = TypedDict(
+    "StartVoiceToneAnalysisTaskResponseTypeDef",
+    {
+        "VoiceToneAnalysisTask": VoiceToneAnalysisTaskTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 CreateSipMediaApplicationResponseTypeDef = TypedDict(
     "CreateSipMediaApplicationResponseTypeDef",
     {
@@ -1819,6 +2279,30 @@ UpdateVoiceConnectorGroupResponseTypeDef = TypedDict(
     },
 )
 
+CreateVoiceProfileDomainResponseTypeDef = TypedDict(
+    "CreateVoiceProfileDomainResponseTypeDef",
+    {
+        "VoiceProfileDomain": VoiceProfileDomainTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetVoiceProfileDomainResponseTypeDef = TypedDict(
+    "GetVoiceProfileDomainResponseTypeDef",
+    {
+        "VoiceProfileDomain": VoiceProfileDomainTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateVoiceProfileDomainResponseTypeDef = TypedDict(
+    "UpdateVoiceProfileDomainResponseTypeDef",
+    {
+        "VoiceProfileDomain": VoiceProfileDomainTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 GetVoiceConnectorEmergencyCallingConfigurationResponseTypeDef = TypedDict(
     "GetVoiceConnectorEmergencyCallingConfigurationResponseTypeDef",
     {
@@ -1958,6 +2442,21 @@ UpdatePhoneNumberResponseTypeDef = TypedDict(
     },
 )
 
+SpeakerSearchTaskTypeDef = TypedDict(
+    "SpeakerSearchTaskTypeDef",
+    {
+        "SpeakerSearchTaskId": str,
+        "SpeakerSearchTaskStatus": str,
+        "CallDetails": CallDetailsTypeDef,
+        "SpeakerSearchDetails": SpeakerSearchDetailsTypeDef,
+        "CreatedTimestamp": datetime,
+        "UpdatedTimestamp": datetime,
+        "StartedTimestamp": datetime,
+        "StatusMessage": str,
+    },
+    total=False,
+)
+
 GetVoiceConnectorStreamingConfigurationResponseTypeDef = TypedDict(
     "GetVoiceConnectorStreamingConfigurationResponseTypeDef",
     {
@@ -1981,3 +2480,19 @@ PutVoiceConnectorStreamingConfigurationResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+GetSpeakerSearchTaskResponseTypeDef = TypedDict(
+    "GetSpeakerSearchTaskResponseTypeDef",
+    {
+        "SpeakerSearchTask": SpeakerSearchTaskTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartSpeakerSearchTaskResponseTypeDef = TypedDict(
+    "StartSpeakerSearchTaskResponseTypeDef",
+    {
+        "SpeakerSearchTask": SpeakerSearchTaskTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
